@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 use Moo;
 use strictures 2;
@@ -91,6 +91,8 @@ sub BUILD {
     my ( $self, $args ) = @_;
     die 'Schema and database may not be used at the same time.'
         if $self->has_database and $self->has_schema;
+    die 'No schema or database given.'
+        unless $self->has_database or $self->has_schema;
 }
 
 1;
@@ -107,7 +109,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -170,7 +172,7 @@ Create a new C<Test::SQLite> object.
 
 =head2 BUILD
 
-Ensure that we are given either a B<database> or a B<schema>.
+Ensure that we are not given both a B<database> and a B<schema>.
 
 =head1 THANK YOU
 
